@@ -192,6 +192,13 @@ gdk_imlib_load_colors(char *file)
 
   f = fopen(file, "r");
   if (!f)
+   {
+     char *ctmp = basename (file);
+     if (ctmp) { sprintf (s, "%s/%s", SYSCONFDIR, ctmp);
+     f = open (s, "r"); }
+   }
+
+ if (!f)
       return 0;
 
   i = 0;
